@@ -1,8 +1,9 @@
-package analyzer //nolint:testpackage
+package analyzer //nolint:testpackage // Testing of private api.
 
 import (
 	"reflect"
 	"regexp"
+	"strings"
 	"testing"
 
 	"github.com/Antonboom/testifylint/internal/checkers"
@@ -17,45 +18,66 @@ func Test_newCheckers(t *testing.T) {
 		checkers.NewFloatCompare(),
 		checkers.NewBoolCompare(),
 		checkers.NewEmpty(),
-		checkers.NewLen(),
 		checkers.NewNegativePositive(),
 		checkers.NewCompares(),
+		checkers.NewContains(),
 		checkers.NewErrorNil(),
 		checkers.NewNilCompare(),
 		checkers.NewErrorIsAs(),
+		checkers.NewEncodedCompare(),
 		checkers.NewExpectedActual(),
+		checkers.NewLen(),
+		checkers.NewEqualValues(),
+		checkers.NewRegexp(),
 		checkers.NewSuiteExtraAssertCall(),
 		checkers.NewSuiteDontUsePkg(),
 		checkers.NewUselessAssert(),
+		checkers.NewFormatter(),
 	}
 	allRegularCheckers := []checkers.RegularChecker{
 		checkers.NewFloatCompare(),
 		checkers.NewBoolCompare(),
 		checkers.NewEmpty(),
-		checkers.NewLen(),
 		checkers.NewNegativePositive(),
 		checkers.NewCompares(),
+		checkers.NewContains(),
 		checkers.NewErrorNil(),
 		checkers.NewNilCompare(),
 		checkers.NewErrorIsAs(),
+		checkers.NewEncodedCompare(),
 		checkers.NewExpectedActual(),
+		checkers.NewLen(),
+		checkers.NewEqualValues(),
+		checkers.NewRegexp(),
 		checkers.NewSuiteExtraAssertCall(),
 		checkers.NewSuiteDontUsePkg(),
 		checkers.NewUselessAssert(),
+		checkers.NewFormatter(),
 	}
 
 	enabledByDefaultAdvancedCheckers := []checkers.AdvancedChecker{
 		checkers.NewBlankImport(),
 		checkers.NewGoRequire(),
 		checkers.NewRequireError(),
+		checkers.NewSuiteBrokenParallel(),
+		checkers.NewSuiteMethodSignature(),
+		checkers.NewSuiteSubtestRun(),
 	}
 	allAdvancedCheckers := []checkers.AdvancedChecker{
 		checkers.NewBlankImport(),
 		checkers.NewGoRequire(),
 		checkers.NewRequireError(),
+		checkers.NewSuiteBrokenParallel(),
+		checkers.NewSuiteMethodSignature(),
+		checkers.NewSuiteSubtestRun(),
 		checkers.NewSuiteTHelper(),
 	}
 
+	formatterWithoutEnabledOptions := checkers.RegularChecker(checkers.NewFormatter().
+		SetCheckFormatString(false).
+		SetRequireFFuncs(false).
+		SetRequireStringMsg(false))
+
 	cases := []struct {
 		name        string
 		cfg         config.Config
@@ -65,7 +87,7 @@ func Test_newCheckers(t *testing.T) {
 		{
 			name:        "no config",
 			cfg:         config.Config{},
-			expRegular:  enabledByDefaultRegularCheckers,
+			expRegular:  replace(enabledByDefaultRegularCheckers, formatterWithoutEnabledOptions),
 			expAdvanced: enabledByDefaultAdvancedCheckers,
 		},
 		{
@@ -99,7 +121,7 @@ func Test_newCheckers(t *testing.T) {
 					checkers.NewSuiteTHelper().Name(),
 				},
 			},
-			expRegular: filter(allRegularCheckers, config.KnownCheckersValue{
+			expRegular: filter(replace(allRegularCheckers, formatterWithoutEnabledOptions), config.KnownCheckersValue{
 				checkers.NewRequireError().Name(),
 				checkers.NewSuiteTHelper().Name(),
 			}),
@@ -115,7 +137,7 @@ func Test_newCheckers(t *testing.T) {
 					checkers.NewSuiteTHelper().Name(),
 				},
 			},
-			expRegular:  allRegularCheckers,
+			expRegular:  replace(enabledByDefaultRegularCheckers, formatterWithoutEnabledOptions),
 			expAdvanced: allAdvancedCheckers,
 		},
 		{
@@ -127,7 +149,7 @@ func Test_newCheckers(t *testing.T) {
 					checkers.NewRequireError().Name(),
 				},
 			},
-			expRegular: filter(enabledByDefaultRegularCheckers, config.KnownCheckersValue{
+			expRegular: filter(replace(enabledByDefaultRegularCheckers, formatterWithoutEnabledOptions), config.KnownCheckersValue{
 				checkers.NewNilCompare().Name(),
 				checkers.NewErrorNil().Name(),
 				checkers.NewRequireError().Name(),
@@ -218,10 +240,12 @@ func Test_newCheckers(t *testing.T) {
 			}
 
 			if !reflect.DeepEqual(tt.expRegular, rc) {
-				t.Fatalf("unexpected regular checkers: %#v != %#v", rc, tt.expRegular)
+				t.Fatalf("unexpected regular checkers:\n%v\n\n!=\n\n%v\n\ncheck the checkers config!",
+					checkerNames(rc), checkerNames(tt.expRegular))
 			}
 			if !reflect.DeepEqual(tt.expAdvanced, ac) {
-				t.Fatalf("unexpected expAdvanced checkers: %#v != %#v", ac, tt.expAdvanced)
+				t.Fatalf("unexpected expAdvanced checkers:\n%v\n\n!=\n\n%v\n\ncheck the checkers config!",
+					checkerNames(ac), checkerNames(tt.expAdvanced))
 			}
 		})
 	}
@@ -251,3 +275,26 @@ func filter[T checkers.Checker](in []T, exclude config.KnownCheckersValue) []T {
 	}
 	return result
 }
+
+func replace[T checkers.Checker](in []T, with T) []T {
+	result := make([]T, 0)
+	for _, v := range in {
+		if v.Name() == with.Name() {
+			result = append(result, with)
+		} else {
+			result = append(result, v)
+		}
+	}
+	return result
+}
+
+func checkerNames[T checkers.Checker](in []T) string {
+	var b strings.Builder
+	for i, c := range in {
+		b.WriteString(c.Name())
+		if i != len(in)-1 {
+			b.WriteString("\n")
+		}
+	}
+	return b.String()
+}
