@@ -11,26 +11,41 @@ import (
 
 // Empty detects situations like
 //
-//	assert.Len(t, arr, 0)
-//	assert.Equal(t, 0, len(arr))
-//	assert.EqualValues(t, 0, len(arr))
-//	assert.Exactly(t, 0, len(arr))
-//	assert.LessOrEqual(t, len(arr), 0)
-//	assert.GreaterOrEqual(t, 0, len(arr))
-//	assert.Less(t, len(arr), 0)
-//	assert.Greater(t, 0, len(arr))
-//	assert.Less(t, len(arr), 1)
-//	assert.Greater(t, 1, len(arr))
+// assert.Len(t, arr, 0)
+// assert.Zero(t, str)
+// assert.Zero(t, len(arr))
+// assert.Equal(t, 0, len(arr))
+// assert.EqualValues(t, 0, len(arr))
+// assert.Exactly(t, 0, len(arr))
+// assert.LessOrEqual(t, len(arr), 0)
+// assert.GreaterOrEqual(t, 0, len(arr))
+// assert.Less(t, len(arr), 1)
+// assert.Greater(t, 1, len(arr))
+// assert.Equal(t, "", str)
+// assert.EqualValues(t, "", str)
+// assert.Exactly(t, "", str)
+// assert.Equal(t, “, str)
+// assert.EqualValues(t, “, str)
+// assert.Exactly(t, “, str)
 //
-//	assert.NotEqual(t, 0, len(arr))
-//	assert.NotEqualValues(t, 0, len(arr))
-//	assert.Less(t, 0, len(arr))
-//	assert.Greater(t, len(arr), 0)
+// assert.Positive(t, len(arr))
+// assert.NotZero(t, str)
+// assert.NotZero(t, len(arr))
+// assert.NotEqual(t, 0, len(arr))
+// assert.NotEqualValues(t, 0, len(arr))
+// assert.Greater(t, len(arr), 0)
+// assert.Less(t, 0, len(arr))
+// assert.NotEqual(t, "", str)
+// assert.NotEqualValues(t, "", str)
+// assert.NotEqual(t, “, str)
+// assert.NotEqualValues(t, “, str)
 //
 // and requires
 //
 //	assert.Empty(t, arr)
 //	assert.NotEmpty(t, arr)
+//
+// Also Empty removes extra `len` call.
 type Empty struct{}
 
 // NewEmpty constructs Empty checker.
@@ -44,22 +59,41 @@ func (checker Empty) Check(pass *analysis.Pass, call *CallMeta) *analysis.Diagno
 	return checker.checkNotEmpty(pass, call)
 }
 
-func (checker Empty) checkEmpty(pass *analysis.Pass, call *CallMeta) *analysis.Diagnostic { //nolint:gocognit
+func (checker Empty) checkEmpty(pass *analysis.Pass, call *CallMeta) *analysis.Diagnostic { //nolint:gocognit // It is ok.
 	newUseEmptyDiagnostic := func(replaceStart, replaceEnd token.Pos, replaceWith ast.Expr) *analysis.Diagnostic {
 		const proposed = "Empty"
 		return newUseFunctionDiagnostic(checker.Name(), call, proposed,
-			newSuggestedFuncReplacement(call, proposed, analysis.TextEdit{
+			analysis.TextEdit{
 				Pos:     replaceStart,
 				End:     replaceEnd,
 				NewText: analysisutil.NodeBytes(pass.Fset, replaceWith),
-			}),
-		)
+			})
+	}
+
+	if len(call.Args) == 0 {
+		return nil
+	}
+	a := call.Args[0]
+
+	switch call.Fn.NameFTrimmed {
+	case "Zero":
+		if hasStringType(pass, a) {
+			return newUseEmptyDiagnostic(a.Pos(), a.End(), a)
+		}
+		if lenArg, ok := isBuiltinLenCall(pass, a); ok {
+			return newUseEmptyDiagnostic(a.Pos(), a.End(), lenArg)
+		}
+
+	case "Empty":
+		if lenArg, ok := isBuiltinLenCall(pass, a); ok {
+			return newRemoveLenDiagnostic(pass, checker.Name(), call, a, lenArg)
+		}
 	}
 
 	if len(call.Args) < 2 {
 		return nil
 	}
-	a, b := call.Args[0], call.Args[1]
+	b := call.Args[1]
 
 	switch call.Fn.NameFTrimmed {
 	case "Len":
@@ -68,6 +102,10 @@ func (checker Empty) checkEmpty(pass *analysis.Pass, call *CallMeta) *analysis.D
 		}
 
 	case "Equal", "EqualValues", "Exactly":
+		if isEmptyStringLit(a) {
+			return newUseEmptyDiagnostic(a.Pos(), b.End(), b)
+		}
+
 		arg1, ok1 := isLenCallAndZero(pass, a, b)
 		arg2, ok2 := isLenCallAndZero(pass, b, a)
 
@@ -98,25 +136,53 @@ func (checker Empty) checkEmpty(pass *analysis.Pass, call *CallMeta) *analysis.D
 	return nil
 }
 
-func (checker Empty) checkNotEmpty(pass *analysis.Pass, call *CallMeta) *analysis.Diagnostic { //nolint:gocognit
+func (checker Empty) checkNotEmpty(pass *analysis.Pass, call *CallMeta) *analysis.Diagnostic { //nolint:gocognit // It is ok.
 	newUseNotEmptyDiagnostic := func(replaceStart, replaceEnd token.Pos, replaceWith ast.Expr) *analysis.Diagnostic {
 		const proposed = "NotEmpty"
 		return newUseFunctionDiagnostic(checker.Name(), call, proposed,
-			newSuggestedFuncReplacement(call, proposed, analysis.TextEdit{
+			analysis.TextEdit{
 				Pos:     replaceStart,
 				End:     replaceEnd,
 				NewText: analysisutil.NodeBytes(pass.Fset, replaceWith),
-			}),
-		)
+			})
+	}
+
+	if len(call.Args) == 0 {
+		return nil
+	}
+	a := call.Args[0]
+
+	switch call.Fn.NameFTrimmed {
+	case "Positive":
+		if lenArg, ok := isBuiltinLenCall(pass, a); ok {
+			return newUseNotEmptyDiagnostic(a.Pos(), a.End(), lenArg)
+		}
+
+	case "NotZero":
+		if hasStringType(pass, a) {
+			return newUseNotEmptyDiagnostic(a.Pos(), a.End(), a)
+		}
+		if lenArg, ok := isBuiltinLenCall(pass, a); ok {
+			return newUseNotEmptyDiagnostic(a.Pos(), a.End(), lenArg)
+		}
+
+	case "NotEmpty":
+		if lenArg, ok := isBuiltinLenCall(pass, a); ok {
+			return newRemoveLenDiagnostic(pass, checker.Name(), call, a, lenArg)
+		}
 	}
 
 	if len(call.Args) < 2 {
 		return nil
 	}
-	a, b := call.Args[0], call.Args[1]
+	b := call.Args[1]
 
 	switch call.Fn.NameFTrimmed {
 	case "NotEqual", "NotEqualValues":
+		if isEmptyStringLit(a) {
+			return newUseNotEmptyDiagnostic(a.Pos(), b.End(), b)
+		}
+
 		arg1, ok1 := isLenCallAndZero(pass, a, b)
 		arg2, ok2 := isLenCallAndZero(pass, b, a)
 
