@@ -45,7 +45,8 @@ func pidsWithContext(_ context.Context) ([]int32, error) {
 		return ret, err
 	}
 
-	for _, proc := range kprocs {
+	for i := range kprocs {
+		proc := &kprocs[i]
 		ret = append(ret, int32(proc.Proc.P_pid))
 	}
 
@@ -74,7 +75,7 @@ func (p *Process) NameWithContext(ctx context.Context) (string, error) {
 		if err != nil {
 			return "", err
 		}
-		if len(cmdName) > 0 {
+		if cmdName != "" {
 			extendedName := filepath.Base(cmdName)
 			if strings.HasPrefix(extendedName, p.name) {
 				name = extendedName
@@ -137,7 +138,7 @@ func (p *Process) GidsWithContext(_ context.Context) ([]uint32, error) {
 	return gids, nil
 }
 
-func (p *Process) GroupsWithContext(_ context.Context) ([]uint32, error) {
+func (*Process) GroupsWithContext(_ context.Context) ([]uint32, error) {
 	return nil, common.ErrNotImplementedError
 	// k, err := p.getKProc()
 	// if err != nil {
@@ -152,7 +153,7 @@ func (p *Process) GroupsWithContext(_ context.Context) ([]uint32, error) {
 	// return groups, nil
 }
 
-func (p *Process) TerminalWithContext(_ context.Context) (string, error) {
+func (*Process) TerminalWithContext(_ context.Context) (string, error) {
 	return "", common.ErrNotImplementedError
 	/*
 		k, err := p.getKProc()
@@ -178,7 +179,7 @@ func (p *Process) NiceWithContext(_ context.Context) (int32, error) {
 	return int32(k.Proc.P_nice), nil
 }
 
-func (p *Process) IOCountersWithContext(_ context.Context) (*IOCountersStat, error) {
+func (*Process) IOCountersWithContext(_ context.Context) (*IOCountersStat, error) {
 	return nil, common.ErrNotImplementedError
 }
 
@@ -238,7 +239,7 @@ func (p *Process) getKProc() (*unix.KinfoProc, error) {
 // Return value deletes Header line(you must not input wrong arg).
 // And splited by Space. Caller have responsibility to manage.
 // If passed arg pid is 0, get information from all process.
-func callPsWithContext(ctx context.Context, arg string, pid int32, threadOption bool, nameOption bool) ([][]string, error) {
+func callPsWithContext(ctx context.Context, arg string, pid int32, threadOption, nameOption bool) ([][]string, error) {
 	var cmd []string
 	switch {
 	case pid == 0: // will get from all processes.
@@ -278,42 +279,49 @@ func callPsWithContext(ctx context.Context, arg string, pid int32, threadOption
 	return ret, nil
 }
 
-var (
+type dlFuncs struct {
+	lib *common.Library
+
 	procPidPath      common.ProcPidPathFunc
 	procPidInfo      common.ProcPidInfoFunc
 	machTimeBaseInfo common.MachTimeBaseInfoFunc
-)
+}
 
-func registerFuncs() (*common.Library, error) {
+func loadProcFuncs() (*dlFuncs, error) {
 	lib, err := common.NewLibrary(common.System)
 	if err != nil {
 		return nil, err
 	}
 
-	procPidPath = common.GetFunc[common.ProcPidPathFunc](lib, common.ProcPidPathSym)
-	procPidInfo = common.GetFunc[common.ProcPidInfoFunc](lib, common.ProcPidInfoSym)
-	machTimeBaseInfo = common.GetFunc[common.MachTimeBaseInfoFunc](lib, common.MachTimeBaseInfoSym)
-
-	return lib, nil
+	return &dlFuncs{
+		lib:              lib,
+		procPidPath:      common.GetFunc[common.ProcPidPathFunc](lib, common.ProcPidPathSym),
+		procPidInfo:      common.GetFunc[common.ProcPidInfoFunc](lib, common.ProcPidInfoSym),
+		machTimeBaseInfo: common.GetFunc[common.MachTimeBaseInfoFunc](lib, common.MachTimeBaseInfoSym),
+	}, nil
 }
 
-func getTimeScaleToNanoSeconds() float64 {
+func (f *dlFuncs) getTimeScaleToNanoSeconds() float64 {
 	var timeBaseInfo common.MachTimeBaseInfo
 
-	machTimeBaseInfo(uintptr(unsafe.Pointer(&timeBaseInfo)))
+	f.machTimeBaseInfo(uintptr(unsafe.Pointer(&timeBaseInfo)))
 
 	return float64(timeBaseInfo.Numer) / float64(timeBaseInfo.Denom)
 }
 
+func (f *dlFuncs) Close() {
+	f.lib.Close()
+}
+
 func (p *Process) ExeWithContext(_ context.Context) (string, error) {
-	lib, err := registerFuncs()
+	funcs, err := loadProcFuncs()
 	if err != nil {
 		return "", err
 	}
-	defer lib.Close()
+	defer funcs.Close()
 
 	buf := common.NewCStr(common.PROC_PIDPATHINFO_MAXSIZE)
-	ret := procPidPath(p.Pid, buf.Addr(), common.PROC_PIDPATHINFO_MAXSIZE)
+	ret := funcs.procPidPath(p.Pid, buf.Addr(), common.PROC_PIDPATHINFO_MAXSIZE)
 
 	if ret <= 0 {
 		return "", fmt.Errorf("unknown error: proc_pidpath returned %d", ret)
@@ -335,11 +343,11 @@ type vnodePathInfo struct {
 // error.
 // Note: This might also work for other *BSD OSs.
 func (p *Process) CwdWithContext(_ context.Context) (string, error) {
-	lib, err := registerFuncs()
+	funcs, err := loadProcFuncs()
 	if err != nil {
 		return "", err
 	}
-	defer lib.Close()
+	defer funcs.Close()
 
 	// Lock OS thread to ensure the errno does not change
 	runtime.LockOSThread()
@@ -347,8 +355,8 @@ func (p *Process) CwdWithContext(_ context.Context) (string, error) {
 
 	var vpi vnodePathInfo
 	const vpiSize = int32(unsafe.Sizeof(vpi))
-	ret := procPidInfo(p.Pid, common.PROC_PIDVNODEPATHINFO, 0, uintptr(unsafe.Pointer(&vpi)), vpiSize)
-	errno, _ := lib.Dlsym("errno")
+	ret := funcs.procPidInfo(p.Pid, common.PROC_PIDVNODEPATHINFO, 0, uintptr(unsafe.Pointer(&vpi)), vpiSize)
+	errno, _ := funcs.lib.Dlsym("errno")
 	err = *(**unix.Errno)(unsafe.Pointer(&errno))
 	if errors.Is(err, unix.EPERM) {
 		return "", ErrorNotPermitted
@@ -396,7 +404,7 @@ func (p *Process) cmdlineSlice() ([]string, error) {
 	// of the process.
 	for _, arg := range args[1:] {
 		argStr = string(arg)
-		if len(argStr) > 0 {
+		if argStr != "" {
 			if nargs > 0 {
 				argSlice = append(argSlice, argStr)
 				nargs--
@@ -432,29 +440,29 @@ func (p *Process) CmdlineWithContext(ctx context.Context) (string, error) {
 }
 
 func (p *Process) NumThreadsWithContext(_ context.Context) (int32, error) {
-	lib, err := registerFuncs()
+	funcs, err := loadProcFuncs()
 	if err != nil {
 		return 0, err
 	}
-	defer lib.Close()
+	defer funcs.Close()
 
 	var ti ProcTaskInfo
-	procPidInfo(p.Pid, common.PROC_PIDTASKINFO, 0, uintptr(unsafe.Pointer(&ti)), int32(unsafe.Sizeof(ti)))
+	funcs.procPidInfo(p.Pid, common.PROC_PIDTASKINFO, 0, uintptr(unsafe.Pointer(&ti)), int32(unsafe.Sizeof(ti)))
 
 	return int32(ti.Threadnum), nil
 }
 
 func (p *Process) TimesWithContext(_ context.Context) (*cpu.TimesStat, error) {
-	lib, err := registerFuncs()
+	funcs, err := loadProcFuncs()
 	if err != nil {
 		return nil, err
 	}
-	defer lib.Close()
+	defer funcs.Close()
 
 	var ti ProcTaskInfo
-	procPidInfo(p.Pid, common.PROC_PIDTASKINFO, 0, uintptr(unsafe.Pointer(&ti)), int32(unsafe.Sizeof(ti)))
+	funcs.procPidInfo(p.Pid, common.PROC_PIDTASKINFO, 0, uintptr(unsafe.Pointer(&ti)), int32(unsafe.Sizeof(ti)))
 
-	timescaleToNanoSeconds := getTimeScaleToNanoSeconds()
+	timescaleToNanoSeconds := funcs.getTimeScaleToNanoSeconds()
 	ret := &cpu.TimesStat{
 		CPU:    "cpu",
 		User:   float64(ti.Total_user) * timescaleToNanoSeconds / 1e9,
@@ -464,14 +472,14 @@ func (p *Process) TimesWithContext(_ context.Context) (*cpu.TimesStat, error) {
 }
 
 func (p *Process) MemoryInfoWithContext(_ context.Context) (*MemoryInfoStat, error) {
-	lib, err := registerFuncs()
+	funcs, err := loadProcFuncs()
 	if err != nil {
 		return nil, err
 	}
-	defer lib.Close()
+	defer funcs.Close()
 
 	var ti ProcTaskInfo
-	procPidInfo(p.Pid, common.PROC_PIDTASKINFO, 0, uintptr(unsafe.Pointer(&ti)), int32(unsafe.Sizeof(ti)))
+	funcs.procPidInfo(p.Pid, common.PROC_PIDTASKINFO, 0, uintptr(unsafe.Pointer(&ti)), int32(unsafe.Sizeof(ti)))
 
 	ret := &MemoryInfoStat{
 		RSS:  uint64(ti.Resident_size),
