@@ -17,7 +17,6 @@ import (
 	"strings"
 
 	"golang.org/x/tools/go/types/typeutil"
-	"golang.org/x/tools/internal/aliases"
 	"golang.org/x/tools/internal/typeparams"
 )
 
@@ -35,7 +34,7 @@ type falconResult struct {
 // information but preserve type equivalence classes.
 //
 // Fresh names are deliberately obscure to avoid shadowing even if a
-// callee parameter has a nanme like "int" or "any".
+// callee parameter has a name like "int" or "any".
 type falconType struct {
 	Name string
 	Kind types.BasicKind // string/number/bool
@@ -65,7 +64,7 @@ type falconType struct {
 //     cannot be eliminated by substitution as its argument value is
 //     negative.
 //
-//   - When inlining sub("", 2, 1), all three parameters cannot be be
+//   - When inlining sub("", 2, 1), all three parameters cannot be
 //     simultaneously eliminated by substitution without violating i
 //     <= len(s) and j <= len(s), but the parameters i and j could be
 //     safely eliminated without s.
@@ -423,13 +422,14 @@ func (st *falconState) expr(e ast.Expr) (res any) { // = types.TypeAndValue | as
 		if e.Type != nil {
 			_ = st.expr(e.Type)
 		}
-		t := deref(typeparams.CoreType(deref(tv.Type)))
-		var uniques []ast.Expr
+		t := types.Unalias(typeparams.Deref(tv.Type))
+		ct := typeparams.CoreType(t)
+		var mapKeys []ast.Expr // map key expressions; must be distinct if constant
 		for _, elt := range e.Elts {
 			if kv, ok := elt.(*ast.KeyValueExpr); ok {
-				if !is[*types.Struct](t) {
+				if is[*types.Map](ct) {
 					if k := st.expr(kv.Key); k != nil {
-						uniques = append(uniques, st.toExpr(k))
+						mapKeys = append(mapKeys, st.toExpr(k))
 					}
 				}
 				_ = st.expr(kv.Value)
@@ -437,38 +437,24 @@ func (st *falconState) expr(e ast.Expr) (res any) { // = types.TypeAndValue | as
 				_ = st.expr(elt)
 			}
 		}
-		if uniques != nil {
-			// Inv: not a struct.
-
-			// The type T in constraint T{...} depends on the CompLit:
-			// - for a basic-keyed map, use map[K]int;
-			// - for an interface-keyed map, use map[any]int;
-			// - for a slice, use []int;
-			// - for an array or *array, use [n]int.
-			// The last two entail progressively stronger index checks.
-			var ct ast.Expr // type syntax for constraint
-			switch t := aliases.Unalias(t).(type) {
-			case *types.Map:
-				if types.IsInterface(t.Key()) {
-					ct = &ast.MapType{
-						Key:   makeIdent(st.any),
-						Value: makeIdent(st.int),
-					}
-				} else {
-					ct = &ast.MapType{
-						Key:   makeIdent(st.typename(t.Key())),
-						Value: makeIdent(st.int),
-					}
+		if len(mapKeys) > 0 {
+			// Inlining a map literal may replace variable key expressions by constants.
+			// All such constants must have distinct values.
+			// (Array and slice literals do not permit non-constant keys.)
+			t := ct.(*types.Map)
+			var typ ast.Expr
+			if types.IsInterface(t.Key()) {
+				typ = &ast.MapType{
+					Key:   makeIdent(st.any),
+					Value: makeIdent(st.int),
 				}
-			case *types.Array: // or *array
-				ct = &ast.ArrayType{
-					Len: makeIntLit(t.Len()),
-					Elt: makeIdent(st.int),
+			} else {
+				typ = &ast.MapType{
+					Key:   makeIdent(st.typename(t.Key())),
+					Value: makeIdent(st.int),
 				}
-			default:
-				panic(t)
 			}
-			st.emitUnique(ct, uniques)
+			st.emitUnique(typ, mapKeys)
 		}
 		// definitely non-constant
 
@@ -508,7 +494,7 @@ func (st *falconState) expr(e ast.Expr) (res any) { // = types.TypeAndValue | as
 				if kX != nil {
 					// string
 					x = st.toExpr(kX)
-				} else if arr, ok := deref(st.info.TypeOf(e.X).Underlying()).(*types.Array); ok {
+				} else if arr, ok := typeparams.CoreType(typeparams.Deref(st.info.TypeOf(e.X))).(*types.Array); ok {
 					// array, *array
 					x = &ast.CompositeLit{
 						Type: &ast.ArrayType{
@@ -573,7 +559,7 @@ func (st *falconState) expr(e ast.Expr) (res any) { // = types.TypeAndValue | as
 		if kX != nil {
 			// string
 			x = st.toExpr(kX)
-		} else if arr, ok := deref(st.info.TypeOf(e.X).Underlying()).(*types.Array); ok {
+		} else if arr, ok := typeparams.CoreType(typeparams.Deref(st.info.TypeOf(e.X))).(*types.Array); ok {
 			// array, *array
 			x = &ast.CompositeLit{
 				Type: &ast.ArrayType{
