@@ -18,5 +18,5 @@ type t3 struct {
 func fn() {
 	v1 := t1{1, 2}
 	_ = t2{v1.a, v1.b} //@ diag(`should convert v1`)
-	_ = t3{v1.a, v1.b} //@ diag(`should convert v1`)
+	_ = t3{v1.a, v1.b}
 }
